@@ -43,6 +43,10 @@
 #include <npfunctions.h>
 #include "npupp.h"
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #ifndef HIBYTE
 #define HIBYTE(x) ((((uint32_t)(x)) & 0xff00) >> 8)
 #endif
@@ -80,12 +84,21 @@ NPError OSCALL NP_GetEntryPoints(NPPluginFuncs * pFuncs)
 
 #endif                          /* XP_WIN */
 
+#ifdef NPAPI_USE_CONSTCHARS
+const char *NPP_GetMIMEDescription();
+
+const char *NP_GetMIMEDescription()
+{
+    return NPP_GetMIMEDescription();
+}
+#else
 char *NPP_GetMIMEDescription();
 
 char *NP_GetMIMEDescription()
 {
     return NPP_GetMIMEDescription();
 }
+#endif
 
 NPError NP_GetValue(void *future, NPPVariable variable, void *value)
 {
