@@ -42,10 +42,14 @@
 #include "plugin_setup.h"
 #include "plugin_types.h"
 #include "plugin_dbus.h"
+#ifdef HAVE_NSPR
+#include <nspr/nspr.h>
+#else
 #include <nsIPrefBranch.h>
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
 #include <nsISupportsPrimitives.h>
+#endif
 #include <dlfcn.h>
 
 static NPObject *sWindowObj;
@@ -887,8 +891,11 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
         return -1;
     }
 
-    if (strstr((char *) buffer, "ICY 200 OK") != NULL || strstr((char *) buffer, "Content-length:") != NULL     // If item is a block of jpeg images, just stream it
-        || strstr((char *) buffer, "<HTML>") != NULL || item->streaming == TRUE) {
+    if (strstr((char *) buffer, "ICY 200 OK") != NULL
+        || strstr((char *) buffer, "Content-length:") != NULL
+        || strstr((char *) buffer, "<HTML>") != NULL || item->streaming == TRUE
+        || strstr(item->src, "file://") != NULL) {
+        // If item is a block of jpeg images, just stream it
         //   || stream->lastmodified == 0) {    this is not valid for many sites
 
         // printf("BUFFER='%s'\n", buffer);
@@ -1320,7 +1327,7 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
     ListItem *item = (ListItem *) clientp;
     gdouble percent, rate;
     gchar *text;
-    gboolean ok_to_play;
+    gboolean ok_to_play = FALSE;
     gint id;
     gboolean ready;
     gboolean newwindow;
@@ -1364,8 +1371,11 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
                                         rate);
                 }
                 send_signal_with_string(plugin, item, "SetProgressText", text);
-                if (!item->opened)
-                    send_signal_with_string(plugin, item, "SetURL", item->src);
+                if (!item->opened) {
+                    //open_location (plugin, item, TRUE);
+                    //item->opened = TRUE;
+                    //send_signal_with_string(plugin, item, "SetURL", item->src);
+                }
                 if (plugin->post_dom_events && plugin->id != NULL) {
                     postDOMEvent(plugin->mInstance, plugin->id, "qt_progress");
                     postDOMEvent(plugin->mInstance, plugin->id, "qt_durationchange");
@@ -1376,22 +1386,25 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
                 item->lastsize = item->localsize;
             }
         }
+
+        // Disable playing of partially cached apple.com files, mplayer seems to crash on these files
+        /*
         if (!item->opened) {
             if ((item->localsize >= (plugin->cache_size * 1024)) && (percent >= 0.2)) {
-                printf("Setting to play because %i > %i\n", item->localsize,
-                       plugin->cache_size * 1024);
+                //printf("Setting to play because %i > %i\n", item->localsize,
+                //       plugin->cache_size * 1024);
                 ok_to_play = TRUE;
             }
             if (ok_to_play == FALSE && (item->localsize > (plugin->cache_size * 2 * 1024))
                 && (plugin->cache_size >= 512)) {
-                printf("Setting to play because %i > %i (double cache)\n", item->localsize,
-                       plugin->cache_size * 2 * 1024);
+                //printf("Setting to play because %i > %i (double cache)\n", item->localsize,
+                //       plugin->cache_size * 2 * 1024);
                 ok_to_play = TRUE;
             }
             if (ok_to_play == FALSE) {
                 if (item->bitrate == 0 && item->bitrate_requests < 5
                     && ((gint) (percent * 100) > item->bitrate_requests)) {
-                    item->bitrate = request_bitrate(plugin, item, item->local);
+                    //item->bitrate = request_bitrate(plugin, item, item->local);
                     item->bitrate_requests++;
                 }
                 if (item->bitrate > 0) {
@@ -1407,6 +1420,11 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
             }
 
         }
+        */
+        
+        // try downloading entire file
+        ok_to_play = FALSE;
+        
         // if not opened, over cache level and not an href target then try and open it
         if ((!item->opened) && ok_to_play == TRUE) {
             id = item->controlid;
@@ -1418,6 +1436,7 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
             if (!item->streaming) {
                 printf("in progress_callback\n");
                 plugin->playlist = list_parse_qt(plugin->playlist, item);
+                plugin->playlist = list_parse_qt2(plugin->playlist, item);
                 plugin->playlist = list_parse_asx(plugin->playlist, item);
                 plugin->playlist = list_parse_qml(plugin->playlist, item);
                 plugin->playlist = list_parse_ram(plugin->playlist, item);
@@ -1457,6 +1476,7 @@ int progress_callback(void *clientp, double dltotal, double dlnow, double ultota
             g_free(path);
         }
 
+
     }
 
     return 0;
@@ -1493,13 +1513,14 @@ gpointer CURLGetURLNotify(gpointer data)
 
             }
             fclose(local);
-            printf("fetched %s to %s\n", item->src, item->local);
+            printf("fetched %s to %s opened = %i\n", item->src, item->local, item->opened);
+            send_signal_with_double(plugin, item, "SetCachePercent", 1.0);
             send_signal_with_double(plugin, item, "SetCachePercent", 0.0);
             item->retrieved = TRUE;
         }
 
 
-        if ((!item->opened)) {
+        if (!item->opened) {
             id = item->controlid;
             path = g_strdup(item->path);
             ready = item->playerready;
@@ -1509,13 +1530,14 @@ gpointer CURLGetURLNotify(gpointer data)
             if (!item->streaming) {
                 printf("in CURLGetURLNotify\n");
                 plugin->playlist = list_parse_qt(plugin->playlist, item);
+                plugin->playlist = list_parse_qt2(plugin->playlist, item);
                 plugin->playlist = list_parse_asx(plugin->playlist, item);
                 plugin->playlist = list_parse_qml(plugin->playlist, item);
                 plugin->playlist = list_parse_ram(plugin->playlist, item);
             }
             // printf("item->play = %i\n", item->play);
             // printf("item->src = %i\n", item->src);
-            // printf("calling open_location from Write\n");
+            // printf("calling open_location from CURLGetURLNotify\n");
             if (item->play) {
                 send_signal_with_integer(plugin, item, "SetGUIState", PLAYING);
                 open_location(plugin, item, TRUE);
@@ -1549,6 +1571,7 @@ gpointer CURLGetURLNotify(gpointer data)
 
         }
     }
+    return NULL;
 }
 
 
@@ -1642,8 +1665,7 @@ class ScriptablePluginObjectBase:public NPObject {
   public:
     ScriptablePluginObjectBase(NPP npp)
     :mNpp(npp) {
-    }
-    virtual ~ ScriptablePluginObjectBase() {
+    } virtual ~ ScriptablePluginObjectBase() {
     }
 
     // Virtual NPObject hooks called through this base class. Override
@@ -1803,8 +1825,7 @@ class ScriptablePluginObjectControls:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObjectControls(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    }
-    virtual bool HasMethod(NPIdentifier name);
+    } virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -1927,8 +1948,7 @@ class ScriptablePluginObjectMedia:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObjectMedia(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    }
-    virtual bool HasMethod(NPIdentifier name);
+    } virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -2053,8 +2073,7 @@ class ScriptablePluginObjectSettings:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObjectSettings(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    }
-    virtual bool HasMethod(NPIdentifier name);
+    } virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -2153,8 +2172,7 @@ class ScriptablePluginObjectError:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObjectError(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    }
-    virtual bool HasMethod(NPIdentifier name);
+    } virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -2250,8 +2268,7 @@ class ScriptablePluginObject:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObject(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    }
-    virtual bool HasMethod(NPIdentifier name);
+    } virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -2616,21 +2633,24 @@ bool ScriptablePluginObject::GetProperty(NPIdentifier name, NPVariant * result)
 
     if (name == status_id) {
         pPlugin->GetPlayState(&state);
-        switch(state) {
-            case STATE_PLAYING:
-                status = g_strdup(_("Playing"));
-                break;
-            case STATE_PAUSED:
-                status = g_strdup(_("Paused"));
-                break;
-            case STATE_STOPPED:
-                status = g_strdup(_("Stopped"));
-                break;
-            case STATE_BUFFERING:
-                status = g_strdup_printf(_("Buffering %2.1lf%%"), request_double_value(pPlugin, pPlugin->lastopened, "GetCachePercent") * 100.0);
-                break;
-            default:
-                status = g_strdup(_("Unknown Status"));
+        switch (state) {
+        case STATE_PLAYING:
+            status = g_strdup(_("Playing"));
+            break;
+        case STATE_PAUSED:
+            status = g_strdup(_("Paused"));
+            break;
+        case STATE_STOPPED:
+            status = g_strdup(_("Stopped"));
+            break;
+        case STATE_BUFFERING:
+            status =
+                g_strdup_printf(_("Buffering %2.1lf%%"),
+                                request_double_value(pPlugin, pPlugin->lastopened,
+                                                     "GetCachePercent") * 100.0);
+            break;
+        default:
+            status = g_strdup(_("Unknown Status"));
         }
         // printf("Status = %s\n", status);
         STRINGZ_TO_NPVARIANT(status, *result);
